Apache Jena Fuseki - validation

# Fuseki – validation

Use this page to validate SPARQL queries or RDF data.

Forthcoming feature – not yet working.

## Validate as:

- SPARQL
- SPARQL extended syntax
- Turtle
- TriG
- N-Triples
- N-Quads

## Output format:

- SPARQL
- SPARQL algebra
- SPARQL algebra (quads)
- SPARQL algebra (with optimizations)
- SPARQL algebra (quads, with optimizations)

perform validation

## Validation output